@@ -12,7 +12,10 @@ finally:
 
 
 from nessvec import util
-from nessvec import glove  # noqa
+from nessvec import files  # noqa
+# from nessvec import hypervec  # requires annoy.AnnoyIndex
+from nessvec import glove
 
-__all__ = [util, glove]
+
+__all__ = ['util', 'files', 'glove']  # , hypervec]
 # from nessvec import nessvectors as word2vec  # noqa
